@@ -114,12 +114,10 @@ class CGCalendar extends CGExtensions
 	  $this->SetParameterType('searchtemplate',CLEAN_STRING); // todo, doc this.
 	  $this->SetParameterType('searchresulttemplate',CLEAN_STRING); // todo, doc this.
 	  $this->SetParameterType('searchresultpage',CLEAN_STRING); // todo, doc this
+	  $this->SetParameterType('displayforday',CLEAN_INT);
 
-	  $this->CreateParameter('myeventstemplate','',$this->Lang('help_param_myeventstemplate'));
 	  $this->SetParameterType('myeventstemplate',CLEAN_STRING); 
-	  $this->CreateParameter('editeventtemplate','',$this->Lang('help_param_editeventtemplate'));
 	  $this->SetParameterType('editeventtemplate',CLEAN_STRING); 
-	  $this->CreateParameter('editpage','',$this->Lang('help_param_editpage'));
       $this->SetParameterType('editpage',CLEAN_INT);
 
 	  $this->SetParameterType('unique_only',CLEAN_INT);
@@ -134,21 +132,45 @@ class CGCalendar extends CGExtensions
       $this->RegisterRoute('/'.$this->GetPreference('url_prefix','calendar').'\/(?P<returnid>[0-9]+)\/(?P<event_id>[0-9]+)-.*$/',
 			   array('action'=>'default',
 				 'display'=>'event'));
-// 	  if( $this->GetPreference('url_prefix') != 'calendar' )
-// 		{
-// 		  // for backwards compatiblity.
-// 		  $this->RegisterRoute('/calendar\/(?P<returnid>[0-9]+)\/(?P<event_id>[0-9]+)-.*$/',
-// 							   array('action'=>'default',
-// 									 'display'=>'event'));
-// 		}
+
+	  if( version_compare(CMS_VERSION,'1.10-beta0') < 0 )
+		{
+		  $this->InitializeAdmin();
+		}
     }
   
 
+  function InitializeFrontend()
+  {
+	$this->SetParameters();
+  }
+
+
+  function InitializeAdmin()
+  {
+	$this->CreateParameter('myeventstemplate','',$this->Lang('help_param_myeventstemplate'));
+	$this->CreateParameter('editeventtemplate','',$this->Lang('help_param_editeventtemplate'));
+	$this->CreateParameter('editpage','',$this->Lang('help_param_editpage'));
+  }
+
+  public function LazyLoadFrontend()
+  {
+	return FALSE;
+  }
+
+
+  public function LazyLoadAdmin()
+  {
+	return TRUE;
+  }
+
+
   function GetName()
-    {
-      return 'CGCalendar';
-    }
+  {
+	return 'CGCalendar';
+  }
   
+
   function GetFriendlyName()
     {
       return $this->Lang('cal_calendar');
@@ -194,12 +216,12 @@ class CGCalendar extends CGExtensions
 
   function GetVersion()
     {
-      return '1.6';
+      return '1.9.6';
     }
 
   function GetDependencies()
     {
-      return array('CGExtensions'=>'1.24');
+      return array('CGExtensions'=>'1.25');
     }
 
   function GetDescription($lang = 'en_US')
@@ -224,7 +246,7 @@ class CGCalendar extends CGExtensions
 
   function MinimumCMSVersion()
     {
-      return '1.9.1';
+      return '1.9.4.3';
     }
 
   function GetChangeLog()
@@ -513,8 +535,8 @@ class CGCalendar extends CGExtensions
   function GetCategoryName($id)
   {
 	$db = $this->GetDb();
-	$sql = 'SELECT name FROM '.$this->categories_table_name.'
-             WHERE id = ?';
+	$sql = 'SELECT category_name FROM '.$this->categories_table_name.'
+             WHERE category_id = ?';
 	$name = $db->GetOne($query,array($id));
 	return $name;
   }
@@ -658,6 +680,7 @@ class CGCalendar extends CGExtensions
     {
       $lang['date'] = $this->Lang('cal_date');
       $lang['summary'] = $this->Lang('cal_summary');
+
       $lang['details'] = $this->Lang('cal_details');
       $lang['return'] = $this->Lang('cal_return');
       $lang['to'] = $this->Lang('cal_to');
