@@ -798,7 +798,7 @@ $fieldtext = '';
 //////////////////////////////////////////////////////////////
 // Update Search
 /////////////////////////////////////////////////////////////
-$search =& $this->GetModuleInstance('Search');
+$search = $this->GetModuleInstance('Search');
 if( $search != FALSE )
   {
     $text = "{$event['event_title']} {$event['event_summary']} {$event['event_details']}";
@@ -874,7 +874,7 @@ $parms['event_date_start'] = $event['event_date_start'];
 $parms['event_date_end'] = $event['event_date_end'];
 $parms['event_created_by'] = $user_id;
 $parms['event_id'] = $event['event_id'];
-if( $event['event_id'] > -1 )
+if( !$do_insert )
   {
     $eventname = 'EventEdited';
   }
