@@ -43,7 +43,7 @@ if( !$this->CheckPermission("Modify Calendar") ) {
 $error="";
 $message="";
 $this->SetCurrentTab('fields');
-$db =& $this->GetDb(); /* @var $db ADOConnection */
+$db = $this->GetDb(); /* @var $db ADOConnection */
 
 $ids = $params['field_ids'];
 $names = $params['field_names'];
