@@ -43,8 +43,8 @@ function NoBreak($string) {
 function AdminDisplayManageEvents(&$mod, $id, &$parameters, $returnid)
 {
   global $gCms;
-  $smarty =& $gCms->GetSmarty();
-  $db =& $gCms->GetDb();
+  $smarty = $gCms->GetSmarty();
+  $db = $gCms->GetDb();
 
   if( isset($parameters['filter_conflicting']) )
     {
@@ -74,6 +74,7 @@ function AdminDisplayManageEvents(&$mod, $id, &$parameters, $returnid)
   $smarty->assign('input_categories',$mod->CreateInputDropdown($id,'category_filter',$category_array, -1, $category_filter));
   $smarty->assign('input_submit',$mod->CreateInputSubmit($id,'submit',$mod->Lang('cal_go')));
 
+  $smarty->assign('import_link',$mod->CreateLink($id, 'admin_import', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/import.gif', $mod->Lang('cal_import_events'),'','','systemicon'), array(), '', false, false, '').' '. $mod->CreateLink($id, 'admin_import', $returnid, $mod->Lang('cal_import_events'), array(), '', false, false, 'class="pageoptions"'));
   $smarty->assign('addlink',
 		  $mod->CreateLink($id, 'admin_add_event', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/newobject.gif', $mod->Lang('cal_add_event'),'','','systemicon'), array(), '', false, false, '') .' '. $mod->CreateLink($id, 'admin_add_event', $returnid, $mod->Lang('cal_add_event'), array(), '', false, false, 'class="pageoptions"'));
   $smarty->assign('show_children',
@@ -135,10 +136,9 @@ function AdminDisplayManageEvents(&$mod, $id, &$parameters, $returnid)
 	  $smarty->assign('events',$entries);
 	}
       $rs->Close();
+
       $smarty->assign('delete_selected',
-		      $mod->CreateInputSubmit($id,'delete_selected',$mod->Lang('deletetagged'),'','',$mod->lang('confirmdeletetagged')));
-      $smarty->assign('import_link',$mod->CreateLink($id, 'admin_import', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/import.gif', $mod->Lang('cal_import_events'),'','','systemicon'), array(), '', false, false, '').' '. $mod->CreateLink($id, 'admin_import', $returnid, $mod->Lang('cal_import_events'), array(), '', false, false, 'class="pageoptions"'));
-      
+		      $mod->CreateInputSubmit($id,'delete_selected',$mod->Lang('deletetagged'),'','',$mod->lang('confirmdeletetagged')));      
     }
 
   echo $mod->ProcessTemplate('admin_events_tab.tpl');
