@@ -39,7 +39,7 @@
 function DisplayCalendar(&$module, $id, &$parameters, $returnid)
 {
   global $gCms;
-  $smarty =& $gCms->GetSmarty();
+  $smarty = $gCms->GetSmarty();
 	
   $categories_table_name = $module->categories_table_name;
   $event_field_values_table_name = $module->event_field_values_table_name;
@@ -77,11 +77,11 @@ function DisplayCalendar(&$module, $id, &$parameters, $returnid)
 
   if (isset($parameters['detailpage']))
     {
-      $manager =& $gCms->GetHierarchyManager();
-      $node =& $manager->sureGetNodeByAlias($parameters['detailpage']);
+      $manager = $gCms->GetHierarchyManager();
+      $node = $manager->sureGetNodeByAlias($parameters['detailpage']);
       if (isset($node))
 	{
-	  $content =& $node->GetContent();
+	  $content = $node->GetContent();
 	  if (isset($content))
 	    {
 	      $detailpage = $content->Id();
@@ -89,7 +89,7 @@ function DisplayCalendar(&$module, $id, &$parameters, $returnid)
 	}
       else
 	{
-	  $node =& $manager->sureGetNodeById($parameters['detailpage']);
+	  $node = $manager->sureGetNodeById($parameters['detailpage']);
 	  if (isset($node))
 	    {
 	      $detailpage = $parameters['detailpage'];
@@ -127,7 +127,7 @@ function DisplayCalendar(&$module, $id, &$parameters, $returnid)
   $last_day_of_month = mktime(0, 0, 0, $next_month['month'], 0, $next_month['year']);
 
 
-  $db =& $module->GetDb();
+  $db = $module->GetDb();
   $sql = "SELECT DISTINCT $events_table_name.*
 				FROM $events_table_name\n";
   if($category)
@@ -320,6 +320,8 @@ function DisplayCalendar(&$module, $id, &$parameters, $returnid)
 	  // stick the event into the $days array
 	  for($i = $first_day_of_event_in_this_month; $i <= $last_day_of_event_in_this_month; $i++)
 	    {
+	      $row['first_day'] = ($i == $first_day_of_event_in_this_month)?TRUE:FALSE;
+	      $row['last_day'] = ($i == $last_day_of_event_in_this_month)?TRUE:FALSE;
 	      $days[$i]['events'][] = $row;
 	    }
 	}
@@ -333,7 +335,7 @@ function DisplayCalendar(&$module, $id, &$parameters, $returnid)
 	{
 	  $days[$today]['class'] = '';
 	}
-      $days[$today]['class'] .= ' calendar-today';
+      $days[$today]['class'] .= 'calendar-today';
     }
 
 
