@@ -38,17 +38,17 @@
 
 function DisplayEvent(&$module, $id, &$parameters, $returnid)
 {
-  global $gCms;
-  $smarty =& $gCms->GetSmarty();
+  $gCms = cmsms();
+  $smarty = $gCms->GetSmarty();
 
 	$detailpage = 1;
 	if (isset($parameters['detailpage']))
 	{
-		$manager =& $gCms->GetHierarchyManager();
-		$node =& $manager->sureGetNodeByAlias($parameters['detailpage']);
+		$manager = $gCms->GetHierarchyManager();
+		$node = $manager->sureGetNodeByAlias($parameters['detailpage']);
 		if (isset($node))
 		{
-			$content =& $node->GetContent();
+			$content = $node->GetContent();
 			if (isset($content))
 			{
 				$detailpage = $content->Id();
@@ -56,7 +56,7 @@ function DisplayEvent(&$module, $id, &$parameters, $returnid)
 		}
 		else
 		{
-			$node =& $manager->sureGetNodeById($parameters['detailpage']);
+			$node = $manager->sureGetNodeById($parameters['detailpage']);
 			if (isset($node))
 			{
 				$detailpage = $parameters['detailpage'];
@@ -74,7 +74,7 @@ function DisplayEvent(&$module, $id, &$parameters, $returnid)
 	$event_id = get_parameter_value($parameters, 'event_id', 'next');
 	$use_session = get_parameter_value($parameters, 'use_session', true);
 
-	$db =& $module->GetDb();
+	$db = cmsms()->GetDb();
 	$sql = "SELECT DISTINCT $events_table_name.*
 				FROM $events_table_name ";
 
@@ -90,7 +90,7 @@ function DisplayEvent(&$module, $id, &$parameters, $returnid)
 	else 
 	  {
 	    // no event
-	    echo '<div class="calendar-error">'.$this->Lang('error_event_not_found',$event_id).'</div>';
+	    echo '<div class="calendar-error">'.$module->Lang('error_event_not_found',$event_id).'</div>';
 	    return;
 	  }
 
@@ -99,7 +99,7 @@ function DisplayEvent(&$module, $id, &$parameters, $returnid)
 	if(!is_object($rs) || $rs->RecordCount() != 1)
 	{
 	  // something's wrong
-	  echo '<div class="calendar-error">'.$this->Lang('error_event_not_found',$event_id).'</div>';
+	  echo '<div class="calendar-error">'.$module->Lang('error_event_not_found',$event_id).'</div>';
 	  return;
 	}
 
@@ -109,16 +109,18 @@ function DisplayEvent(&$module, $id, &$parameters, $returnid)
 	    $event_id = $event['event_id'];
 	  }
 
-	$userops =& $gCms->GetUserOperations();
-	$userlist =& $userops->LoadUsers();
+	$userops = $gCms->GetUserOperations();
+	$userlist = $userops->LoadUsers();
 	// print_r($userlist);
 	$users = array();
 	foreach ($userlist as $oneuser)
 	{
 		$users[$oneuser->id] = $oneuser;
 	}
-	$event['author'] = $users[$event['event_created_by']]->username;
-	$event['authorname'] = $users[$event['event_created_by']]->firstname.' '.$users[$event['event_created_by']]->lastname;
+	if( isset($users[$event['event_created_by']]) ) {
+	  $event['author'] = $users[$event['event_created_by']]->username;
+	  $event['authorname'] = $users[$event['event_created_by']]->firstname.' '.$users[$event['event_created_by']]->lastname;
+        }
 
 	// pick up categories
 	$sql = "SELECT DISTINCT $categories_table_name.*
@@ -259,4 +261,4 @@ function DisplayEvent(&$module, $id, &$parameters, $returnid)
 	}
 }
 
-?>
\ No newline at end of file
+?>
