@@ -1,6 +1,63 @@
 <?php
 # Simple Language file for the Calendar module.
 # Copyright (c) 2004 by Rob Allen <rob@akrabat.com>
+$lang['error_insufficientparams'] = 'Insufficient Parameters';
+$lang['column_delimiter'] = 'Import file column delimiter';
+$lang['import_completed'] = 'Import Complete';
+$lang['num_imported'] = 'Number of events created: %d';
+$lang['import_lines'] = 'Number of lines processed from file: %d';
+$lang['errors'] = 'Errors';
+$lang['error_csvfirstlineinvalidfield'] = 'Field: %s is not recognized, and is not a custom field';
+$lang['info_csv_format'] = <<<EOT
+<h4>CSV File Format Information.</h4>
+<ul>
+  <li>General Information:
+   <ul>
+     <li>The file must be an ASCII file with unix (preferred), dos, or mac line endings.</li>
+     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
+     <li>Empty lines are ignored</li>
+     <li>Field delimiters are user controllable, however a delimiter can be used as a value within a field if the field is delimited by double quotes.</li>
+     <li>Rows are delimited by newline chars (as above).</li>
+   </ul>
+  </li>
+  <li>The Field Map:
+   <ul>
+    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
+    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
+    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
+   </ul>
+  </li>
+  <li>The Data Rows:
+   <ul>
+    <li>The start time, title, and description fields must not be empty.</li>
+<li>Start and End Times:</li>
+  <ul>
+   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
+   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
+   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
+   <li>If the end time column is empty, then no end time value will be created in the database.</li>
+  </ul>
+</li>
+<li>Categories
+  <ul>
+   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
+   <li>Category names are case sensitive.</li>
+   <li>Categories are not created if they do not exist.</li>
+  </ul>
+</li>
+<li>Custom Fields:
+  <ul>
+    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
+    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
+    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
+  </ul>
+  </li>
+  </ul>
+</li>
+<li>A sample csv file exists in the modules source code directory.</li>
+</ul>
+EOT;
+$lang['prompt_csv_file'] = 'Select Import File';
 $lang['delete'] = 'Delete';
 $lang['cd_company'] = 'Company Directory Company';
 $lang['dflt_urlprefix'] = 'Default URL prefix for Pretty URLS';
@@ -242,6 +299,9 @@ $lang['eventhelp-CategoryDeleted'] = '
 </ul>
 ';
 
+$lang['error_csv_insert'] = 'Error importing event from csv at line %d';
+$lang['error_csvfirstlinefldnotfound'] = 'A required field: %s, could not be found in the csv file header line';
+$lang['error_csvinvalidfirstline'] = 'Could not find a valid first line of the CSV file';
 $lang['msg_eventadded'] = 'Event Added';
 $lang['error_noeventname'] = 'A name for the event is required';
 $lang['error_noupload'] = 'ERROR: No uploaded file found';
@@ -454,7 +514,9 @@ in order to add, edit, or delete calendar event entries.</p>
   <tr>
      <td>category</td>
      <td>Only display items for that category. Leaving unset, will show all categories. Note that
-	 you can limit to multiple categories by separating each one with a comma.<em>(optional)</em></td>
+	 you can limit to multiple categories by separating each one with a comma. This parameter can be 
+         used with the myevents action and with the various display options.  If multiple category names are specified
+         a match is done on ANY of the categories specified. <em>(optional)</em></td>
   </tr>
 
   <tr>
@@ -547,7 +609,12 @@ in order to add, edit, or delete calendar event entries.</p>
 
   <tr>
      <td>unique_only</td>
-     <td>Used with display=upcominglist, and with action=search, this parameter allows you to specify that only one event of a certain type should be returned';
+     <td>Used with display=upcominglist, and with action=search, this parameter allows you to specify that only one event with a certain name should be returned.  Default value is 0';
+  </tr>
+
+  <tr>
+     <td>displayforday</td>
+     <td>Used with display=upcominglist, this parameter specifies that 00:01 of the current day should be used for calculating wether an event should be displayed, rather than the current server time.</td>
   </tr>
 
 </table>
@@ -557,8 +624,8 @@ in order to add, edit, or delete calendar event entries.</p>
 
 <h3>Examples</h3>
 <h4>Example of allowing Comments on Calendar events</h4>
-<p>Install the Comments module and put this in your Calendar "Event Template":</p>
-<pre>{cms_module module='comments' modulename='CGCalendar' pageid=\$event.event_id}</pre>
+<p>Install the CGFeedback module and put this in your Calendar "Event Template":</p>
+<pre>{CGFeedBack'key1='CGCalendar' key2=\$event.event_id}</pre>
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
