@@ -1,4 +1,60 @@
 <?php
+$lang['column_delimiter'] = 'Import file column delimiter';
+$lang['import_completed'] = 'Import Complete';
+$lang['num_imported'] = 'Number of events created: %d';
+$lang['import_lines'] = 'Number of lines processed from file: %d';
+$lang['errors'] = 'Erreurs';
+$lang['error_csvfirstlineinvalidfield'] = 'Field: %s is not recognized, and is not a custom field';
+$lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
+<ul>
+  <li>General Information:
+   <ul>
+     <li>The file must be an ASCII file with unix, dos, or (hopefully) mac line endings.</li>
+     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
+     <li>Empty lines are ignore.d</li>
+     <li>Fields are delimited with a , however a , can be used as a value within a field if the field is delimited by double quotes.</li>
+     <li>Rows are delimited by newline chars (as above).</li>
+   </ul>
+  </li>
+  <li>The Field Map:
+   <ul>
+    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
+    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
+    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
+   </ul>
+  </li>
+  <li>The Data Rows:
+   <ul>
+    <li>The start time, title, and description fields must not be empty.</li>
+<li>Start and End Times:</li>
+  <ul>
+   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
+   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
+   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
+   <li>If the end time column is empty, then no end time value will be created in the database.</li>
+  </ul>
+</li>
+<li>Categories
+  <ul>
+   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
+   <li>Category names are case sensitive.</li>
+   <li>Categories are not created if they do not exist.</li>
+  </ul>
+</li>
+<li>Custom Fields:
+  <ul>
+    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
+    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
+    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
+  </ul>
+  </li>
+  </ul>
+</li>
+<li>A sample csv file exists in the modules source code directory.</li>
+</ul>';
+$lang['prompt_csv_file'] = 'Select Import File';
+$lang['delete'] = 'Effacer';
+$lang['cd_company'] = 'Company Directory Company';
 $lang['dflt_urlprefix'] = 'Pr&eacute;fixe d&#039;URL par d&eacute;faut pour &quot;pretty URLS&quot;';
 $lang['dflt_alldayevent'] = 'Les nouveaux &eacute;v&eacute;nements sont des &eacute;v&eacute;nements &quot;jour entier (all day)&quot; par d&eacute;faut';
 $lang['dflt_starttime'] = 'Heure de d&eacute;but par d&eacute;faut pour les nouveaux &eacute;v&eacute;nements';
@@ -6,17 +62,17 @@ $lang['info_dflt_starttime'] = '<em>(S&#039;applique uniquement si les nouveaux
 $lang['search_type'] = 'Type de recherche';
 $lang['search_any'] = 'renvoie le r&eacute;sultat sur n&#039;importe lequel des mots recherch&eacute;s';
 $lang['search_all'] = 'renvoie le r&eacute;sultat de recherche sur tous les mots recherch&eacute;s';
-$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Note : </span>aucune recherche ne peut &ecirc;tre effectu&eacute;e sur &quot;File Upload Fields&quot;.';
+$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Note :</span> les recherches ne peuvent &ecirc;tre utilis&eacute;es que dans les champs de texte. Cocher les autres types de champ n&#039;aura aucun effet sur la recherche.';
 $lang['searchable'] = 'Utilisable comme crit&egrave;re de recherche';
 $lang['help_param_editeventtemplate'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier un autre gabarit d&#039;&eacute;dition d&#039;&eacute;v&eacute;nement (invoqu&eacute; lorsque l&#039;utilisateur cr&eacute;e ou &eacute;dite un &eacute;v&eacute;nement) que celui utilis&eacute; par d&eacute;faut.';
 $lang['help_param_editpage'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier une autre page pour le formulaire d&#039;&eacute;dition.';
 $lang['help_param_myeventstemplate'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier un autre gabarit que celui utilis&eacute; par d&eacute;faut.';
 $lang['cal_edit_event'] = 'Editer un &eacute;v&eacute;nement du calendrier';
 $lang['error_dberror'] = 'Erreur de base de donn&eacute;es';
-$lang['submit'] = 'Sousmettre';
+$lang['submit'] = 'Soumettre';
 $lang['info_sysdflt_editevent_template'] = 'Gabarit syst&egrave;me pour &amp;quot;Editer un &eacute;v&eacute;nement&amp;quot;';
 $lang['info_sysdflt_myevents_template'] = 'Gabarit syst&egrave;me pour &amp;quot;Mes &Eacute;v&eacute;nements&amp;quot;';
-$lang['prompt_feedit_group'] = 'Les membres de ce goupe FEU peuvent ajouter des &eacute;v&eacute;nements';
+$lang['prompt_feedit_group'] = 'Les membres de ce groupe FEU peuvent ajouter des &eacute;v&eacute;nements';
 $lang['prompt_feedit_page'] = 'Page par d&eacute;faut pour le formulaire d&#039;&eacute;dition en frontend.';
 $lang['none'] = 'Aucun';
 $lang['owner'] = 'Propri&eacute;taire';
@@ -32,25 +88,25 @@ $lang['overlap_action_remove'] = 'Effacer silencieusement des &eacute;v&eacute;n
 $lang['overlap_action_error'] = 'Affiche une erreur';
 $lang['prompt_overlap_action'] = 'Ce qu&#039;il devrait se passer quand un conflit est d&eacute;tect&eacute; &agrave; l&#039;&eacute;dition ou &agrave; l&#039;ajout d&#039;un &eacute;v&eacute;nement';
 $lang['error_event_conflict'] = 'Les valeurs sp&eacute;cifi&eacute;es de l&#039;&eacute;v&eacute;nement chevauchent un &eacute;v&eacute;nement existant qui n&#039;autorise pas le conflit.';
-$lang['cal_info_overlap'] = 'S&#039;applique seulement aux &eacute;v&eacute;nements comprotant une heure de fin (ou les &eacute;v&eacute;nements de tous les jours)';
+$lang['cal_info_overlap'] = 'S&#039;applique seulement aux &eacute;v&eacute;nements comportant une heure de fin (ou les &eacute;v&eacute;nements de tous les jours)';
 $lang['cal_overlap'] = 'Autorise les nouveaux &eacute;v&eacute;nements &agrave; chevaucher celui-l&agrave;';
 $lang['prompt_overlap_policy'] = 'Politique de chevauchement d&#039;&eacute;v&eacute;nement';
 $lang['policy_all'] = 'Tous les &eacute;v&eacute;nements peuvent se chevaucher';
 $lang['policy_none'] = 'Aucun &eacute;v&eacute;nement ne peut se chevaucher';
-$lang['policy_individual'] = 'Decid&eacute; sur une base d&#039;&eacute;v&eacute;nement par &eacute;v&eacute;nement';
+$lang['policy_individual'] = 'Choix pour chaque &eacute;v&eacute;nement';
 $lang['lbl_back'] = 'Retour';
 $lang['lbl_templates'] = 'Gabarits';
 $lang['textarea'] = 'Zone de Texte (Textarea)';
 $lang['error_calendar_incompatible'] = 'Nous avons d&eacute;tect&eacute; que le module Calendar est d&eacute;j&agrave; install&eacute;. Ce module n&#039;est pas compatible avec le module Calendar et ne peut pas coexister avec lui sur la m&ecirc;me installation. Veuillez d&eacute;sinstaller le module Calendar';
-$lang['error_event_not_found'] = 'Soit evebt_id n&#039;est pas en base de donn&eacute;e, soit il y en a plus qu&#039;un poss&eacute;dant cet id! (%d)';
+$lang['error_event_not_found'] = 'Soit l&#039;event_id n&#039;est pas pr&eacute;sent en base de donn&eacute;es, soit il y a plus d&#039;un &eacute;v&eacute;nement poss&eacute;dant cet id ! (%d)';
 $lang['first_page'] = '<<';
 $lang['prev_page'] = '<';
 $lang['next_page'] = '>';
 $lang['last_page'] = '>>';
-$lang['page_of'] = 'Page %d de %d';
+$lang['page_of'] = 'Page %d sur %d';
 $lang['search_results'] = 'R&eacute;sultats de la Recherche du Calendrier';
 $lang['search_words'] = 'Mots Recherch&eacute;s';
-$lang['no_results_found'] = 'Aucun r&eacute;sultat trouv&eacute; ne correspondant &agrave; la demande';
+$lang['no_results_found'] = 'Aucun r&eacute;sultat trouv&eacute; correspondant &agrave; la demande';
 $lang['frequency'] = 'Fr&eacute;quence';
 $lang['specified_date'] = 'Utiliser la date sp&eacute;cifi&eacute;e';
 $lang['first_sunday'] = 'Premier dimanche du mois';
@@ -88,7 +144,7 @@ $lang['last_wednesday'] = 'Dernier mercredi du mois';
 $lang['last_thursday'] = 'Dernier jeudi du mois';
 $lang['last_friday'] = 'Dernier vendredi du mois';
 $lang['last_saturday'] = 'Dernier samedi du mois';
-$lang['error_invalid_recur_monthly_freq'] = 'Fr&eacute;quence invalide... vous ne pouvez sp&eacute;cifier ET la date ET d&#039;autres valeur';
+$lang['error_invalid_recur_monthly_freq'] = 'Fr&eacute;quence invalide... vous ne pouvez sp&eacute;cifier ET la date ET d&#039;autres valeurs';
 $lang['searchresulttemplate_addedit'] = 'Ajouter/Modifier un gabarit pour les r&eacute;sultats de recherche';
 $lang['info_searchresult_template_tab'] = 'La liste des gabarits qui sont disponibles pour l&#039;affichage des r&eacute;sultats de la recherche';
 $lang['info_sysdflt_searchresult_template'] = 'Gabarit de formulaire de r&eacute;sultat par d&eacute;faut';
@@ -97,16 +153,16 @@ $lang['error_query_failed'] = 'R&ecirc;quete en base &eacute;chou&eacute;e';
 $lang['error_search_invalid_dates'] = 'Les dates indiqu&eacute;es pour la recherche sont invalides';
 $lang['text'] = 'Texte';
 $lang['search'] = 'Recherche';
-$lang['category'] = 'Categorie';
+$lang['category'] = 'Cat&eacute;gorie';
 $lang['info_sysdflt_search_template'] = 'Gabarit de formulaire de recherche par d&eacute;faut';
 $lang['searchtemplate_addedit'] = 'Ajouter/Modifier un gabarit de formulaire de recherche';
 $lang['info_search_template_tab'] = 'La liste des gabarits qui sont disponibles pour le formulaire de recherche';
-$lang['cal_search_form_templates'] = 'Gabarit du formulaire de recherche';
+$lang['cal_search_form_templates'] = 'Gabarits de formulaire de recherche';
 $lang['max'] = 'max ';
 $lang['times'] = 'fois';
 $lang['on'] = 'on ';
-$lang['areyousure_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir faire ceci ? Si vous poursuivez vous aller effacer de mani&egrave;re d&eacute;finitive toutes les donn&eacute;es associ&eacute;es &agrave; ce module.';
-$lang['post_uninstall'] = 'Le module CGCalendrier a &eacute;t&eacute; d&eacute;sinstall&eacute; et tous les &eacute;v&eacute;nements et les informations de gabarit associ&eacute;s &agrave; ce module ont &eacute;t&eacute; supprim&eacute;s.';
+$lang['areyousure_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir faire ceci ? Si vous poursuivez, vous aller effacer de mani&egrave;re d&eacute;finitive toutes les donn&eacute;es associ&eacute;es &agrave; ce module.';
+$lang['post_uninstall'] = 'Le module Calendrier (CG) a &eacute;t&eacute; d&eacute;sinstall&eacute; et tous les &eacute;v&eacute;nements et les informations de gabarit associ&eacute;s &agrave; ce module ont &eacute;t&eacute; supprim&eacute;s.';
 $lang['fieldupdated'] = 'Champ mis &agrave; jour.';
 $lang['every'] = 'Tous les';
 $lang['or'] = 'ou';
@@ -115,7 +171,7 @@ $lang['error_nocategory'] = 'Vous devez s&eacute;lectionner au moins une cat&eac
 $lang['error_nothingselected'] = 'Rien n&#039;a &eacute;t&eacute; s&eacute;lectionn&eacute; pour l&#039;effacement.';
 $lang['error_eventoverlap'] = 'Vos param&egrave;tres de r&eacute;p&eacute;tition d&#039;&eacute;v&eacute;nement engendrent un chevauchement d&#039;&eacute;v&eacute;nements.';
 $lang['recurs'] = 'R&eacute;p&eacute;titions';
-$lang['error_invalid_dates'] = 'Une ou plusieurs valeur entr&eacute;es dans la date sont incorrectes';
+$lang['error_invalid_dates'] = 'Une ou plusieurs valeurs entr&eacute;es pour la date sont incorrectes';
 $lang['sunday'] = 'Dimanche';
 $lang['monday'] = 'Lundi';
 $lang['tuesday'] = 'Mardi';
@@ -146,11 +202,11 @@ $lang['unlimited'] = 'Illimit&eacute;';
 $lang['max_recur_events'] = 'Nombre maximum de sous-&eacute;v&eacute;nements';
 $lang['use_to_date'] = 'Sp&eacute;cifier une date de fin diff&eacute;rente ?';
 $lang['cancel'] = 'Annuler';
-$lang['show_child_events'] = 'Afficher les sous-&eacute;v&eacute;nements <em>(peu causer un affichage long)</em>';
+$lang['show_child_events'] = 'Afficher les sous-&eacute;v&eacute;nements <em>(peut causer un affichage tr&egrave;s long)</em>';
 $lang['n/a'] = 'n/a ';
 $lang['recurs_until'] = 'R&eacute;p&eacute;tition jusqu&#039;&agrave;';
 $lang['parent'] = 'Parent ';
-$lang['recur_period'] = 'Periode de r&eacute;p&eacute;tition';
+$lang['recur_period'] = 'P&eacute;riode de r&eacute;p&eacute;tition';
 $lang['filter'] = 'Filtre';
 $lang['start_date'] = 'Date de d&eacute;but';
 $lang['end_date'] = 'Date de fin';
@@ -225,6 +281,9 @@ $lang['eventhelp-CategoryDeleted'] = '<p>Envoy&eacute; quand une cat&eacute;gori
 <li>\&quot;category_order\&quot; - L&#039;ordre de tri de la cat&eacute;gorie</li>
 </ul>
 ';
+$lang['error_csv_insert'] = 'Error importing event from csv at line %d';
+$lang['error_csvfirstlinefldnotfound'] = 'A required field: %s, could not be found in the csv file header line';
+$lang['error_csvinvalidfirstline'] = 'Could not find a valid first line of the CSV file';
 $lang['msg_eventadded'] = '&Eacute;v&eacute;nement ajout&eacute;';
 $lang['error_noeventname'] = 'Un nom pour l&#039;&eacute;v&eacute;nement doit &ecirc;tre d&eacute;finit';
 $lang['error_noupload'] = 'ERREUR&nbsp;: Aucun fichier upload&eacute; trouv&eacute;';
@@ -236,7 +295,7 @@ $lang['error_csvfilenotfound'] = 'ERREUR&nbsp;: Impossible de trouver le fichier
 $lang['error_cantopenfile'] = 'ERREUR&nbsp;: Impossible d&#039;ouvrir le fichier';
 $lang['error_categoryexists'] = 'ERREUR&nbsp;: Une cat&eacute;gorie avec le nom %s existe d&eacute;j&agrave;';
 $lang['cal_id'] = 'Id ';
-$lang['cal_calendar'] = 'Calendrier';
+$lang['cal_calendar'] = 'Calendrier (CG)';
 $lang['cal_default_templates'] = 'Gabarits par d&eacute;faut';
 $lang['cal_description'] = 'Ajout, &eacute;dition et suppression d&#039;&eacute;v&eacute;nements';
 $lang['cal_addevent'] = 'Ajouter un &eacute;v&eacute;nement';
@@ -313,7 +372,7 @@ $lang['showfutureyears'] = 'Nombre d&#039;ann&eacute;es autoris&eacute;es dans l
 $lang['hidesummary'] = 'Le champ sommaire doit-il &ecirc;tre cach&eacute; ?';
 $lang['hidecontent'] = 'Le champ contenu doit-il &ecirc;tre cach&eacute; ?';
 $lang['category_reminder'] = 'Veuillez s&eacute;lectionner une ou plusieurs cat&eacute;gorie(s) pour cet &eacute;v&eacute;nement';
-$lang['module_example_stylesheet'] = 'CGCalendrier : exemple de CSS';
+$lang['module_example_stylesheet'] = 'Calendrier (CG) : exemple de CSS';
 $lang['error_permission'] = 'Vous avez besoin de la permission appropri&eacute;e (%s) pour acc&eacute;der &agrave; cette fonctionnalit&eacute;';
 $lang['install_postmessage'] = 'Assurez-vous de d&eacute;finir la permission &quot;Modify Calendar&quot; pour les utilisateurs qui administreront les &eacute;v&eacute;nements de calendrier';
 $lang['deletetagged'] = 'Supprimer les &eacute;v&eacute;nements s&eacute;lectionn&eacute;s';
@@ -352,7 +411,7 @@ $lang['fielddeleted'] = 'Champ supprim&eacute;';
 $lang['fields'] = 'Champs par d&eacute;faut';
 $lang['textfield'] = 'Champ texte';
 $lang['uploadfield'] = 'Champ d&#039;upload de fichier';
-$lang['description'] = '<p>Le module CGCalendrier affiche des &eacute;v&eacute;nements sur votre page. Quand le module est install&eacute;, une page d&#039;administration de calendrier est ajout&eacute;e au menu Contenu, et vous permet de g&eacute;rer vos &eacute;v&eacute;nements.</p>';
+$lang['description'] = '<p>Le module Calendrier (CG) affiche des &eacute;v&eacute;nements sur votre page. Quand le module est install&eacute;, une page d&#039;administration de calendrier est ajout&eacute;e au menu Contenu, et vous permet de g&eacute;rer vos &eacute;v&eacute;nements.</p>';
 $lang['defaultcalendarpage'] = 'Page par d&eacute;faut qui contient le calendrier. Cette page doit contenir la balise smarty qui appelle le calendrier. N&eacute;cessaire si vous utilisez les &quot;pretty URLs&quot;.';
 $lang['uploaddirectory'] = 'Dossier o&ugrave; les fichiers upload&eacute;s doivent &ecirc;tre stock&eacute;s';
 $lang['uploadfiletypes'] = 'Types de fichiers autoris&eacute;s';
@@ -367,7 +426,7 @@ $lang['help_template'] = '<p><b>Affiche le nom de l&#039;auteur :</b></p>
 <code>Auteur : {$event.authorname}</code>
 ';
 $lang['cal_help'] = '		<h3>Notice:</h3>
-		<p>Le module CGCalendrier (Calguy Calendar) Version 1.0  est un fork du module de Calendrier classique, mais CGCalendrier n&#039;est aucunement compatible avec Calendrier.
+		<p>Le module Calendrier (CG) Version 1.0  est un fork du module de Calendrier classique, mais Calendrier  (CG) n&#039;est aucunement compatible avec Calendrier.
 		<h3>Que fait ce module ?</h3>
 		<p>Ce module affiche des &eacute;v&eacute;nements sur vos pages. D&egrave;s que le module est install&eacute;, une page de gestion des &eacute;v&eacute;nements est ajout&eacute;e au menu d&#039;administration qui vous permettra de g&eacute;rer des &eacute;v&eacute;nements.</p>
 		<h3>S&eacute;curit&eacute;</h3>
@@ -551,9 +610,6 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
 ';
-$lang['utma'] = '156861353.1949673112.1265210769.1286953600.1286956518.214';
-$lang['utmz'] = '156861353.1286956518.214.40.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,48121.0.html|utmcmd=referral';
-$lang['qca'] = 'P0-1075820551-1265210768764';
-$lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-483686814-1251229608352';
+$lang['utma'] = '57867837.1772960952774974200.1251229608.1315083144.1315177962.175';
 ?>
\ No newline at end of file
