@@ -1,4 +1,59 @@
 <?php
+$lang['import_completed'] = 'Importazione Completata';
+$lang['num_imported'] = 'Numero di eventi creati: %d';
+$lang['import_lines'] = 'Numero di linee elaborate dal file: %d';
+$lang['errors'] = 'Errori';
+$lang['error_csvfirstlineinvalidfield'] = 'Campo: %s non &egrave; stato riconosciuto e non &egrave; un campo personalizzato';
+$lang['info_csv_format'] = '<h4>Informazioni sul formato CSV.</h4>
+<ul>
+  <li>Informazioni Generali:
+   <ul>
+     <li>Il file dev&#039;essere di tipo ASCII con fine linea di tipo unix, dos, o mac.</li>
+     <li>I commenti iniziano con // <br />Ogni carattere dopo questi su una riga verranno ignorati (compresi quelli tra virgolette e apici).</li>
+     <li>Le linee vuote vengono ignorate.</li>
+     <li>I campi sono delimitati da &quot;,&quot;, tuttavia una &quot;,&quot; pu&ograve; essere utilizzata come valore all&#039;interno di un campo se il campo &egrave; delimitato da virgolette.</li>
+     <li>Le Righe sono delimitate da caratteri di interruzione di linea (come sopra).</li>
+   </ul>
+  </li>
+  <li>The Field Map:
+   <ul>
+    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
+    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
+    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
+   </ul>
+  </li>
+  <li>The Data Rows:
+   <ul>
+    <li>The start time, title, and description fields must not be empty.</li>
+<li>Start and End Times:</li>
+  <ul>
+   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
+   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
+   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
+   <li>If the end time column is empty, then no end time value will be created in the database.</li>
+  </ul>
+</li>
+<li>Categories
+  <ul>
+   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
+   <li>Category names are case sensitive.</li>
+   <li>Categories are not created if they do not exist.</li>
+  </ul>
+</li>
+<li>Custom Fields:
+  <ul>
+    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
+    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
+    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
+  </ul>
+  </li>
+  </ul>
+</li>
+<li>A sample csv file exists in the modules source code directory.</li>
+</ul>';
+$lang['prompt_csv_file'] = 'Selezionare File da Importare';
+$lang['delete'] = 'Elimina';
+$lang['cd_company'] = 'Azienda Directory Company';
 $lang['dflt_urlprefix'] = 'Prefisso URL predefinito per Pretty URL';
 $lang['dflt_alldayevent'] = 'I nuovi eventi sono &quot;Tutto il giorno&quot; di default';
 $lang['dflt_starttime'] = 'Ora di inizio predefinita per i nuovi eventi';
@@ -225,6 +280,9 @@ $lang['eventhelp-CategoryDeleted'] = '<p>Inviato quando viene eliminata una cate
 <li>\&quot;category_order\&quot; - Posizione della categoria nell&#039;ordinamento</li>
 </ul>
 ';
+$lang['error_csv_insert'] = 'Errore durante l&#039;importazione di eventi da csv alla linea %d';
+$lang['error_csvfirstlinefldnotfound'] = 'Un campo richiesto ( %s ) non &egrave; stato trovato nella riga di intestazione del file csv';
+$lang['error_csvinvalidfirstline'] = 'Non &egrave; possibile individuare una prima riga valida nel file CSV';
 $lang['msg_eventadded'] = 'Evento aggiunto';
 $lang['error_noeventname'] = 'Un nome per l&#039;evento &egrave; richiesto';
 $lang['error_noupload'] = 'ERRORE: Non &egrave; stato trovato alcun file caricato';
@@ -534,9 +592,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['utma'] = '156861353.1236385967.1296578145.1298365216.1301560700.6';
-$lang['utmz'] = '156861353.1301560750.6.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
-$lang['qca'] = 'P0-1476505638-1296578145169';
-$lang['utmb'] = '156861353.5.10.1301560700';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.1309687447.1326717301.1326717301.1326717301.1';
+$lang['utmz'] = '156861353.1326717301.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-1222936636-1320224029415';
 ?>
\ No newline at end of file
