@@ -1,12 +1,69 @@
 <?php
+$lang['error_insufficientparams'] = 'Verkeerde Parameters';
+$lang['column_delimiter'] = 'Import bestandskolom delimiter';
+$lang['import_completed'] = 'Importeren voltooid';
+$lang['num_imported'] = 'Aantal aangemaakte events: %d';
+$lang['import_lines'] = 'Aantal regels verwerkt uit het bestand: %d';
+$lang['errors'] = 'Fouten';
+$lang['error_csvfirstlineinvalidfield'] = 'Veld: %s is niet herekend en het is geen specifiek veld';
+$lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
+<ul>
+  <li>General Information:
+   <ul>
+     <li>The file must be an ASCII file with unix, dos, or (hopefully) mac line endings.</li>
+     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
+     <li>Empty lines are ignore.d</li>
+     <li>Fields are delimited with a , however a , can be used as a value within a field if the field is delimited by double quotes.</li>
+     <li>Rows are delimited by newline chars (as above).</li>
+   </ul>
+  </li>
+  <li>The Field Map:
+   <ul>
+    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
+    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
+    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
+   </ul>
+  </li>
+  <li>The Data Rows:
+   <ul>
+    <li>The start time, title, and description fields must not be empty.</li>
+<li>Start and End Times:</li>
+  <ul>
+   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
+   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
+   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
+   <li>If the end time column is empty, then no end time value will be created in the database.</li>
+  </ul>
+</li>
+<li>Categories
+  <ul>
+   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
+   <li>Category names are case sensitive.</li>
+   <li>Categories are not created if they do not exist.</li>
+  </ul>
+</li>
+<li>Custom Fields:
+  <ul>
+    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
+    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
+    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
+  </ul>
+  </li>
+  </ul>
+</li>
+<li>A sample csv file exists in the modules source code directory.</li>
+</ul>';
+$lang['prompt_csv_file'] = 'Selecteer importbestand';
+$lang['delete'] = 'Verwijder';
+$lang['cd_company'] = 'Company Directory Bedrijf';
 $lang['dflt_urlprefix'] = 'Te gebruiken prefix voor Pretty URLS';
 $lang['dflt_alldayevent'] = 'Nieuwe evenementen beslaan standaard de gehele dag';
-$lang['dflt_starttime'] = 'Standaard start tijd voor nieuwe evenementen';
+$lang['dflt_starttime'] = 'Standaard starttijd voor nieuwe evenementen';
 $lang['info_dflt_starttime'] = '<em>(alleen van toepassing als nieuwe evenementen niet de gehele dag beslaan.)</em>';
 $lang['search_type'] = 'Zoek Type';
 $lang['search_any'] = 'E&eacute;n of meer zoektermen moeten overeenkomen';
 $lang['search_all'] = 'Alle zoektermen moeten overeenkomen';
-$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Opmerking:</span> &quot;Bestand Upload Velden&quot; zijn niet zoekbaar.';
+$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Opmerking:</span> &quot;Bestand Upload Velden&quot; zijn niet doorzoekbaar.';
 $lang['searchable'] = 'Doorzoekbaar';
 $lang['help_param_editeventtemplate'] = 'Alleen toepasbaar in de myevents-bewerking, deze parameter specificeert een niet-standaard evenementsjabloon om te gebruiken wanneer een gebruiker een evenement aanmaakt of wijzigt.';
 $lang['help_param_editpage'] = 'Enkel toepasbaar op de myevents-bewerking, deze parameter specificeert een andere pagina voor de edit-form';
@@ -223,13 +280,16 @@ $lang['eventhelp-CategoryDeleted'] = '<p>Verzonden na verwijdering van een kalen
 <li>&quot;category_order&quot; - De categoriesorteervolgorde</li>
 </ul>
 ';
+$lang['error_csv_insert'] = 'Fout bij het importeren van het event uit de csv op regel %d';
+$lang['error_csvfirstlinefldnotfound'] = 'Een vereist veld: %s, kon niet worden gevonden in de eerste regel van het csv-bestand';
+$lang['error_csvinvalidfirstline'] = 'Kan geen geldige eerste regel vinden van het CSV-bestand';
 $lang['msg_eventadded'] = 'Gebeurtenis toegevoegd';
 $lang['error_noeventname'] = 'Een naam voor een gebeurtenis is verplicht';
 $lang['error_noupload'] = 'Fout: geen ge&uuml;pload bestand gevonden';
-$lang['error_invalidfilename'] = 'Fout: het ge&uuml;ploade bestand kan niet worden geaccepteerd';
+$lang['error_invalidfilename'] = 'Fout: het ge&uuml;ploade bestand wordt niet geaccepteerd';
 $lang['error_problemwithupload'] = 'Fout: een probleem trad op tijdens het uploaden van het bestand';
-$lang['error_filecopyfailed'] = 'Fout: een probleem trad op tijden het kopi&euml;ren van het bestand naar de uiteindelijke bestemming';
-$lang['error_fileexists'] = 'Fout: een bestand met die naam bestaat al';
+$lang['error_filecopyfailed'] = 'Fout: een probleem trad op tijdens het kopi&euml;ren van het bestand naar de uiteindelijke bestemming';
+$lang['error_fileexists'] = 'Fout: een bestand met deze naam bestaat al';
 $lang['error_csvfilenotfound'] = 'Fout: kan het CSV-bestand niet vinden';
 $lang['error_cantopenfile'] = 'Fout: kan het bestand niet openen';
 $lang['error_categoryexists'] = 'Fout: Een categorie met de naam %s bestaat al';
@@ -303,8 +363,8 @@ $lang['cal_update_categories'] = 'Categorie&euml;n bijwerken';
 $lang['cal_language'] = 'Taal';
 $lang['cal_updatesettings'] = 'Instellingen opslaan';
 $lang['cal_use_twelve_hour_clock'] = 'Gebruik maken van twaalf uurs klok bij de uren-uitvouwmenu&#039;s?';
-$lang['cal_default_category'] = 'Standaardcategorie';
-$lang['cal_update_fields'] = 'Bijgewerkte velden';
+$lang['cal_default_category'] = 'Standaard categorie';
+$lang['cal_update_fields'] = 'Velden opslaan';
 $lang['force_category'] = 'Eis minstens een categorie';
 $lang['showpastyears'] = 'Hoeveel jaren in het verleden zijn toegestaan?';
 $lang['showfutureyears'] = 'Hoeveel jaren in de toekomst zijn toegestaan?';
@@ -340,7 +400,7 @@ $lang['categoryupdated'] = 'Categorie bijgewerkt';
 $lang['categoryadded'] = 'Categorie toegevoegd';
 $lang['eventdeleted'] = 'De gebeurtenis is verwijderd';
 $lang['eventupdated'] = 'De gebeurtenis is bijgewerkt';
-$lang['default_page_error'] = 'Fout: U moet een standaardpagina opgeven om de Kalender met pretty URLs ingeschakeld te kunnen gebruiken.';
+$lang['default_page_error'] = 'Fout: Met de toepassing van Pretty URLs moet een een standaard pagina opgeven worden, om de kalender te kunnen gebruiken.';
 $lang['time_at'] = 'om';
 $lang['type'] = 'Type ';
 $lang['name'] = 'Naam';
@@ -350,8 +410,8 @@ $lang['fielddeleted'] = 'Veld verwijderd';
 $lang['fields'] = 'Instelbare velden';
 $lang['textfield'] = 'Tekstveld';
 $lang['uploadfield'] = 'Bestand upload veld';
-$lang['description'] = '<p>Kalender is een module om gebeurtenissen op een pagina te tonen. Als de module ge&iuml;nstalleerd is, wordt er een Kalenderbeheerpagina aan het Inhoud-menu toegevoegd die het beheer van de gebeurtenissen mogelijk maakt.</p>';
-$lang['defaultcalendarpage'] = 'Standaardpagina die de kalender bevat. Deze pagina moet een Smarty-tag bevatten die de kalender aanroept. Verplicht als u de pretty URL&#039;s gebruikt.';
+$lang['description'] = '<p>Kalender is een module om gebeurtenissen op een pagina te tonen. Als de module ge&iuml;nstalleerd is, wordt er een Kalender beheer pagina aan het Inhoud-menu toegevoegd die het beheer van de gebeurtenissen mogelijk maakt.</p>';
+$lang['defaultcalendarpage'] = 'Standaard pagina die de kalender bevat. Deze pagina moet een Smarty-tag bevatten die de kalender aanroept. Verplicht als u de pretty URL&#039;s gebruikt.';
 $lang['uploaddirectory'] = 'Map waar de ge&uuml;ploade bestanden moeten worden geplaatst';
 $lang['uploadfiletypes'] = 'Toegestane bestandstypen';
 $lang['uploadunique'] = 'Garandeer unieke bestandsnamen';
@@ -547,9 +607,8 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['qca'] = 'P0-94671928-1277843203656';
-$lang['utmz'] = '156861353.1282486936.3.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,13.0.html';
-$lang['utma'] = '156861353.587621801.1277843204.1282482344.1282486936.3';
+$lang['utma'] = '156861353.225590228.1335426399.1335426399.1335426399.1';
+$lang['utmz'] = '156861353.1335426399.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1282486936';
 ?>
\ No newline at end of file
